package main

import (
	"fmt"
	"io"
	"log"
	"os"
	"regexp"
	"sort"
	"strings"
)

var (
	delimRE  = regexp.MustCompile(`\\\{|\{[niuvrgybmcw]+\s|\\\}|\}`)
	colorMap = map[byte]byte{
		'n': 0,
		'i': 1,
		'u': 4,
		'v': 7,
		'r': 31,
		'g': 32,
		'y': 33,
		'b': 34,
		'm': 35,
		'c': 36,
		'w': 37,
	}
)

func main() {
	src, err := io.ReadAll(os.Stdin)
	if err != nil {
		log.Fatal(err)
	}

	_, _ = os.Stdout.Write(delimRE.ReplaceAllFunc(src, func(b []byte) []byte {
		switch b[0] {
		case '\\':
			return []byte{b[1]}
		case '}':
			return []byte("\033[0m")
		case '{':
			mods := make([]byte, len(b)-2)
			for i, c := range b[1 : len(b)-1] {
				mods[i] = colorMap[c]
			}
			sort.Slice(mods, func(i, j int) bool { return mods[i] < mods[j] })

			codes := make([]string, len(mods))
			for i, c := range mods {
				codes[i] = fmt.Sprintf("%d", c)
			}

			return []byte("\033[" + strings.Join(codes, ";") + "m")
		}

		panic("unreachable")
	}))
}
